@@ -55,7 +55,7 @@ our @EXPORT = qw(
 	MCRYPT_FAILED
 );
 
-our $VERSION = '1.0.4';
+our $VERSION = '1.0.5';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -101,7 +101,7 @@ Crypt::Libmcrypt
 
 =head1 VERSION
 
-version 1.0.4
+version 1.0.5
 
 =head1 SYNOPSIS
 
@@ -153,14 +153,7 @@ None by default.
 
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+L<MCrypt|http://mcrypt.sourceforge.net>
 
 =head1 AUTHOR
 
